#
# spec file for package python-pelican
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pelican
Version:        3.7.1
Release:        2.17
Summary:        A tool to generate a static blog from reStructuredText or Markdown input files
License:        AGPL-3.0
Group:          Development/Languages/Python
Url:            http://getpelican.com/
Source:         https://files.pythonhosted.org/packages/source/p/pelican/pelican-%{version}.tar.gz
BuildRequires:  %{python_module Jinja2 >= 2.7}
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module Unidecode}
BuildRequires:  %{python_module blinker}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module feedgenerator >= 1.9}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.4}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2 >= 2.7
Requires:       python-Pygments
Requires:       python-Unidecode
Requires:       python-blinker
Requires:       python-docutils
Requires:       python-feedgenerator >= 1.9
Requires:       python-python-dateutil
Requires:       python-pytz
Requires:       python-six >= 1.4
Requires(post): update-alternatives
Requires(postun): update-alternatives
Suggests:       asciidoc
Suggests:       python-Markdown
Suggests:       python-typogrify
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%python_subpackages

%description
Pelican is a static site generator, written in Python.

* Write your weblog entries directly with your editor of choice in reStructuredText, Markdown or AsciiDoc
* Includes a simple CLI tool to (re)generate the weblog
* Easy to interface with DVCSes and web hooks
* Completely static output is easy to host anywhere

Pelican currently supports:

* Blog articles and pages
* Comments, via an external service
* Theming support (themes are created using Jinja2 templates)
* PDF generation of the articles/pages (optional)
* Publication of articles in multiple languages
* Atom/RSS feeds
* Code syntax highlighting
* Asset management with webassets (optional)
* Import from WordPress, Dotclear, or RSS feeds
* Integration with external tools: Twitter, Google Analytics, etc. (optional)

%prep
%setup -q -n pelican-%{version}
# remove useless shebang
sed -i '1d' \
    pelican/tools/templates/publishconf.py.in \
    pelican/tools/templates/pelicanconf.py.in \
    pelican/tools/pelican_import.py \
    pelican/tools/pelican_themes.py \
    pelican/tools/pelican_quickstart.py
# remove executable bit, this is not a script
chmod -x pelican/tools/templates/publishconf.py.in

%build
%python_build

%install
%python_install
%fdupes %buildroot/%_prefix

for p in pelican pelican-import pelican-quickstart pelican-themes ; do
    %python_clone -a %{buildroot}%{_bindir}/$p
done

%post
%python_install_alternative pelican pelican-import pelican-quickstart pelican-themes

%postun
%python_uninstall_alternative pelican

%files %python_files
%defattr(-,root,root,-)
%doc CONTRIBUTING.rst LICENSE README.rst THANKS docs/*
%python_alternative %{_bindir}/pelican
%python_alternative %{_bindir}/pelican-import
%python_alternative %{_bindir}/pelican-quickstart
%python_alternative %{_bindir}/pelican-themes
%{python_sitelib}/pelican
%{python_sitelib}/pelican-%{version}-py%{python_version}.egg-info

%changelog
* Mon May  8 2017 benoit.monin@gmx.fr
- convert the package to singlespec
* Thu Jan 12 2017 benoit.monin@gmx.fr
- update to version 3.7.1:
  * Fix locale issues in Quickstart script
  * Specify encoding for README and CHANGELOG in setup.py
* Wed Dec 14 2016 benoit.monin@gmx.fr
- update to version 3.7.0:
  * Atom feeds output <content> in addition to <summary>
  * Atom feeds use <published> for the original publication date
    and <updated> for modifications
  * Simplify Atom feed ID generation and support URL fragments
  * Produce category feeds with category-specific titles
  * RSS feeds now default to summary instead of full content — set
    RSS_FEED_SUMMARY_ONLY = False to revert to previous behavior
  * Replace MD_EXTENSIONS with MARKDOWN setting
  * Replace JINJA_EXTENSIONS with more-robust JINJA_ENVIRONMENT
    setting
  * Improve summary truncation logic to handle special characters
    and tags that span multiple lines, using HTML parser instead
    of regular expressions
  * Include summary when looking for intra-site link substitutions
  * Link to authors and index via {author}name and {index} syntax
  * Override widget names via LINKS_WIDGET_NAME and
    SOCIAL_WIDGET_NAME
  * Add INDEX_SAVE_AS option to override default index.html value
  * Remove PAGES context variable for themes in favor of pages
  * SLUG_SUBSTITUTIONS now accepts 3-tuple elements, allowing URL
    slugs to contain non-alphanumeric characters
  * Tag and category slugs can be controlled with greater
    precision using the TAG_SUBSTITUTIONS and
    CATEGORY_SUBSTITUTIONS settings
  * Author slugs can be controlled with greater precision using
    the AUTHOR_SUBSTITUTIONS setting
  * DEFAULT_DATE can be defined as a string
  * Use mtime instead of ctime when DEFAULT_DATE = 'fs'
  * Add --fatal=errors|warnings option for use with continuous
    integration
  * When using generator-level caching, ensure previously-cached
    files are processed instead of just new files
  * Add Python and Pelican version information to debug output
  * Improve compatibility with Python 3.5
  * Comply with and enforce PEP8 guidelines
  * Replace tables in settings documentation with data:: directives
- additionnal changes from version 3.6.3:
  * Fix permissions issue in release tarball
- update source url to https://files.pythonhosted.org
- update version required for feedgenerator and six
* Fri Feb 26 2016 tbechtold@suse.com
- Require python-python-dateutil. package was renamed
* Thu Aug  6 2015 benoit.monin@gmx.fr
- update to version 3.6.2:
  * Fix installation errors related to Unicode in tests
  * Don't show pagination in notmyidea theme if there's only one
    page
  * Make hidden pages available in context
  * Improve URLWrapper comparison
* Tue Jun 16 2015 benoit.monin@gmx.fr
- update to version 3.6.0:
  * Disable caching by default in order to prevent potential
    confusion
  * Improve caching behavior, replacing pickle with cpickle
  * Allow Markdown or reST content in metadata fields other than
    summary
  * Support semicolon-separated author/tag lists
  * Improve flexibility of article sorting
  * Add --relative-urls argument
  * Support devserver listening on addresses other than localhost
  * Unify HTTP server handlers to pelican.server throughout
  * Handle intra-site links to draft posts
  * Move tag_cloud from core to plugin
  * Load default theme’s external resources via HTTPS
  * Import drafts from WordPress XML
  * Improve support for Windows users
  * Enhance logging and test suite
  * Clean up and refactor codebase
  * New signals: all_generators_finalized and page_writer_finalized
* Sun Nov  9 2014 benoit.monin@gmx.fr
- update to pelican 3.5.0
  * Introduce ARTICLE_ORDER_BY and PAGE_ORDER_BY settings
    to control the order of articles and pages
  * Include time zone information in dates rendered in templates
  * Expose the reader name in the metadata for articles and pages
  * Add the ability to store static files along with content in the
    same directory as articles and pages using {attach} in the path
  * Prevent Pelican from raising an exception when there are
    duplicate pieces of metadata in a Markdown file
  * Introduce the TYPOGRIFY_IGNORE_TAGS setting to add HTML tags
    to be ignored by Typogrify
  * Add the ability to use - in date formats to strip leading zeros
  * Ensure feed generation is correctly disabled during quickstart
    configuration
  * Fix PAGE_EXCLUDES and ARTICLE_EXCLUDES from incorrectly
    matching sub-directories
  * Introduce STATIC_EXCLUDE setting to add static file excludes
  * Fix an issue when using PAGINATION_PATTERNS while RELATIVE_URLS
    is enabled
  * Fix feed generation causing links to use the wrong language for
    month names when using other locales
  * Fix an issue where the authors list in the simple template
    wasn't correctly formatted
  * Fix an issue when parsing non-string URLs from settings
  * Improve consistency of debug and warning messages
* Sat Sep 20 2014 benoit.monin@gmx.fr
- add the requires as buildrequires to guarantee they are available
* Mon Sep 15 2014 benoit.monin@gmx.fr
- update to pelican 3.4.0
  * Speed up content generation via new caching mechanism
  * Add selective post generation (instead of always building
    entire site)
  * Many documentation improvements, including switching to
    prettier RtD theme
  * Add support for multiple content and plugin paths
  * Add :modified: metadata field to complement :date:
  * Add support for multiple authors via new :authors: metadata
    field
  * Watch for changes in static directories when in
    auto-regeneration mode
  * Add filters to limit log output when desired
  * Add language support to drafts
  * Add ``SLUGIFY_SOURCE`` setting to control how post slugs are
    generated
  * Fix many issues relating to locale and encoding
  * Apply Typogrify filter to post summary
  * Preserve file metadata (e.g. time stamps) when copying static
    files to output
  * Move AsciiDoc support from Pelican core into separate plugin
  * Produce inline links instead of reference-style links when
    importing content
  * Improve handling of ``IGNORE_FILES`` setting behavior
  * Properly escape symbol characters in tag names (e.g. C++)
  * Minor tweaks for Python 3.4 compatibility
  * Add several new signals
- add new runtime dependency: python-dateutil
- switch to the real package name for Markdown
- add package documentation
- use update-alternatives for pelican binaries
* Fri Dec 27 2013 benoit.monin@gmx.fr
- switch from distribute to setuptools
- remove useless CFLAGS="%%{optflags}"
* Wed Sep 25 2013 benoit.monin@gmx.fr
- Update to pelican 3.3
  * Add Fabfile so Fabric can be used for workflow automation
    instead of Make
  * OUTPUT_RETENTION setting can be used to preserve metadata
    (e.g., VCS data such as .hg and .git) from being removed from
    output directory
  * Tumblr import
  * Improve logic and consistency when cleaning output folder
  * Improve documentation versioning and release automation
  * Improve pagination flexibility
  * Rename signals for better consistency (some plugins may need
    to be updated)
  * Move metadata extraction from generators to readers; metadata
    extraction no longer article-specific
  * Deprecate FILES_TO_COPY in favor of STATIC_PATHS and
    EXTRA_PATH_METADATA
  * Summaries in Markdown posts no longer include footnotes
  * Remove unnecessary whitespace in output via lstrip_blocks Jinja
    parameter
  * Move PDF generation from core to plugin
  * Replace MARKUP setting with READERS
  * Add warning if img tag is missing alt attribute
  * Add support for {} in relative links syntax, besides ||
  * Add support for {tag} and {category} relative links
  * Add a content_written signal
- Require python-Jinja2 >= 2.7
- Require python-feedgenerator >= 1.6
* Sat Jun  8 2013 benoit.monin@gmx.fr
- update to pelican 3.2.2
* Fri Apr 26 2013 benoit.monin@gmx.fr
- update to pelican 3.2
* Thu Mar 28 2013 benoit.monin@gmx.fr
- suggest additional python packages instead of recommending them
* Thu Mar 28 2013 benoit.monin@gmx.fr
- remove useless shebang in python files
* Wed Mar 27 2013 benoit.monin@gmx.fr
- initial package with version 3.1.1
